==> netdata_1.47.5.orig.tar.xz: netdata-1.47.5/src/web/gui/v1/dashboard_v1.cmake <==

    install(FILES src/web/gui/v1/asset-manifest.json
src/web/gui/v1/console.html
src/web/gui/v1/dash-example.html
src/web/gui/v1/dashboard-react.js
src/web/gui/v1/dashboard.css
src/web/gui/v1/dashboard.html
src/web/gui/v1/dashboard.js
src/web/gui/v1/dashboard.slate.css
src/web/gui/v1/demo.html
src/web/gui/v1/demo2.html
src/web/gui/v1/demosites.html
src/web/gui/v1/demosites2.html
src/web/gui/v1/favicon.ico
src/web/gui/v1/goto-host-from-alarm.html
src/web/gui/v1/index-node-view.html
src/web/gui/v1/infographic.html
src/web/gui/v1/manifest.json
src/web/gui/v1/precache-manifest.e2d3811ef5e4b7e75e1f56d6ee92ef2c.js
src/web/gui/v1/refresh-badges.js
src/web/gui/v1/robots.txt
src/web/gui/v1/service-worker.js
src/web/gui/v1/sitemap.xml
src/web/gui/v1/tv-react.html
src/web/gui/v1/tv.html COMPONENT netdata DESTINATION ${WEB_DEST})
    install(FILES src/web/gui/v1/css/bootstrap-3.3.7.css
src/web/gui/v1/css/bootstrap-slate-flat-3.3.7.css
src/web/gui/v1/css/bootstrap-slider-10.0.0.min.css
src/web/gui/v1/css/bootstrap-theme-3.3.7.min.css
src/web/gui/v1/css/bootstrap-toggle-2.2.2.min.css
src/web/gui/v1/css/dashboard.css
src/web/gui/v1/css/dashboard.slate.css COMPONENT netdata DESTINATION ${WEB_DEST}/css)
    install(FILES src/web/gui/v1/fonts/glyphicons-halflings-regular.eot
src/web/gui/v1/fonts/glyphicons-halflings-regular.svg
src/web/gui/v1/fonts/glyphicons-halflings-regular.ttf
src/web/gui/v1/fonts/glyphicons-halflings-regular.woff
src/web/gui/v1/fonts/glyphicons-halflings-regular.woff2 COMPONENT netdata DESTINATION ${WEB_DEST}/fonts)
    install(FILES src/web/gui/v1/images/alert-128-orange.png
src/web/gui/v1/images/alert-128-red.png
src/web/gui/v1/images/alert-multi-size-orange.ico
src/web/gui/v1/images/alert-multi-size-red.ico
src/web/gui/v1/images/alerts.jpg
src/web/gui/v1/images/alerts.png
src/web/gui/v1/images/android-icon-144x144.png
src/web/gui/v1/images/android-icon-192x192.png
src/web/gui/v1/images/android-icon-36x36.png
src/web/gui/v1/images/android-icon-48x48.png
src/web/gui/v1/images/android-icon-72x72.png
src/web/gui/v1/images/android-icon-96x96.png
src/web/gui/v1/images/animated.gif
src/web/gui/v1/images/apple-icon-114x114.png
src/web/gui/v1/images/apple-icon-120x120.png
src/web/gui/v1/images/apple-icon-144x144.png
src/web/gui/v1/images/apple-icon-152x152.png
src/web/gui/v1/images/apple-icon-180x180.png
src/web/gui/v1/images/apple-icon-57x57.png
src/web/gui/v1/images/apple-icon-60x60.png
src/web/gui/v1/images/apple-icon-72x72.png
src/web/gui/v1/images/apple-icon-76x76.png
src/web/gui/v1/images/apple-icon-precomposed.png
src/web/gui/v1/images/apple-icon.png
src/web/gui/v1/images/banner-icon-144x144.png
src/web/gui/v1/images/check-mark-2-128-green.png
src/web/gui/v1/images/check-mark-2-multi-size-green.ico
src/web/gui/v1/images/dashboards.png
src/web/gui/v1/images/favicon-128.png
src/web/gui/v1/images/favicon-16x16.png
src/web/gui/v1/images/favicon-196x196.png
src/web/gui/v1/images/favicon-32x32.png
src/web/gui/v1/images/favicon-96x96.png
src/web/gui/v1/images/favicon.ico
src/web/gui/v1/images/home.png
src/web/gui/v1/images/ms-icon-144x144.png
src/web/gui/v1/images/ms-icon-150x150.png
src/web/gui/v1/images/ms-icon-310x150.png
src/web/gui/v1/images/ms-icon-310x310.png
src/web/gui/v1/images/ms-icon-36x36.png
src/web/gui/v1/images/ms-icon-70x70.png
src/web/gui/v1/images/netdata-logomark.svg
src/web/gui/v1/images/netdata.svg
src/web/gui/v1/images/nodeView.png
src/web/gui/v1/images/nodes.jpg
src/web/gui/v1/images/overview.png
src/web/gui/v1/images/packaging-beta-tag.svg
src/web/gui/v1/images/post.png
src/web/gui/v1/images/pricing.png
src/web/gui/v1/images/seo-performance-128.png COMPONENT netdata DESTINATION ${WEB_DEST}/images)
    install(FILES src/web/gui/v1/lib/bootstrap-3.3.7.min.js
src/web/gui/v1/lib/bootstrap-slider-10.0.0.min.js
src/web/gui/v1/lib/bootstrap-table-1.11.0.min.js
src/web/gui/v1/lib/bootstrap-table-export-1.11.0.min.js
src/web/gui/v1/lib/bootstrap-toggle-2.2.2.min.js
src/web/gui/v1/lib/clipboard-polyfill-be05dad.js
src/web/gui/v1/lib/d3-4.12.2.min.js
src/web/gui/v1/lib/d3pie-0.2.1-netdata-3.js
src/web/gui/v1/lib/dygraph-c91c859.min.js
src/web/gui/v1/lib/dygraph-smooth-plotter-c91c859.js
src/web/gui/v1/lib/fontawesome-all-5.0.1.min.js
src/web/gui/v1/lib/gauge-1.3.2.min.js
src/web/gui/v1/lib/jquery-3.6.0.min.js
src/web/gui/v1/lib/jquery.easypiechart-97b5824.min.js
src/web/gui/v1/lib/jquery.peity-3.2.0.min.js
src/web/gui/v1/lib/jquery.sparkline-2.1.2.min.js
src/web/gui/v1/lib/lz-string-1.4.4.min.js
src/web/gui/v1/lib/pako-1.0.6.min.js
src/web/gui/v1/lib/perfect-scrollbar-0.6.15.min.js
src/web/gui/v1/lib/tableExport-1.6.0.min.js COMPONENT netdata DESTINATION ${WEB_DEST}/lib)
    install(FILES src/web/gui/v1/static/css/2.c454aab8.chunk.css
src/web/gui/v1/static/css/2.c454aab8.chunk.css.map
src/web/gui/v1/static/css/4.a36e3b73.chunk.css
src/web/gui/v1/static/css/4.a36e3b73.chunk.css.map
src/web/gui/v1/static/css/main.53ba10f1.chunk.css
src/web/gui/v1/static/css/main.53ba10f1.chunk.css.map COMPONENT netdata DESTINATION ${WEB_DEST}/static/css)
    install(FILES src/web/gui/v1/static/js/10.a5cd7d0e.chunk.js
src/web/gui/v1/static/js/10.a5cd7d0e.chunk.js.map
src/web/gui/v1/static/js/2.62d105c5.chunk.js
src/web/gui/v1/static/js/2.62d105c5.chunk.js.LICENSE
src/web/gui/v1/static/js/2.62d105c5.chunk.js.map
src/web/gui/v1/static/js/3.f137faca.chunk.js
src/web/gui/v1/static/js/3.f137faca.chunk.js.map
src/web/gui/v1/static/js/4.2dbcd906.chunk.js
src/web/gui/v1/static/js/4.2dbcd906.chunk.js.map
src/web/gui/v1/static/js/5.2f783a54.chunk.js
src/web/gui/v1/static/js/5.2f783a54.chunk.js.LICENSE
src/web/gui/v1/static/js/5.2f783a54.chunk.js.map
src/web/gui/v1/static/js/6.e1951239.chunk.js
src/web/gui/v1/static/js/6.e1951239.chunk.js.map
src/web/gui/v1/static/js/7.c2417fb0.chunk.js
src/web/gui/v1/static/js/7.c2417fb0.chunk.js.map
src/web/gui/v1/static/js/8.b4161ea2.chunk.js
src/web/gui/v1/static/js/8.b4161ea2.chunk.js.map
src/web/gui/v1/static/js/9.a4363968.chunk.js
src/web/gui/v1/static/js/9.a4363968.chunk.js.map
src/web/gui/v1/static/js/main.e248095a.chunk.js
src/web/gui/v1/static/js/main.e248095a.chunk.js.LICENSE
src/web/gui/v1/static/js/main.e248095a.chunk.js.map
src/web/gui/v1/static/js/runtime-main.08abed8f.js
src/web/gui/v1/static/js/runtime-main.08abed8f.js.map COMPONENT netdata DESTINATION ${WEB_DEST}/static/js)
    install(FILES src/web/gui/v1/static/media/ibm-plex-sans-latin-100.245539db.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-100.9a582f3a.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-100italic.1ea7c5d2.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-100italic.3c34cf08.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-200.67524c36.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-200.bf72c841.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-200italic.52df2560.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-200italic.bbc2d552.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-300.10bb6a0a.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-300.9e1c48af.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-300italic.c76f2ab5.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-300italic.d3566d5b.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-400.263d6267.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-400.a2c56f94.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-400italic.272f8611.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-400italic.89a93a1b.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-500.0866c244.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-500.f6d5c5d5.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-500italic.ccd41bd1.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-500italic.ffd12d59.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-600.337b1651.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-600.7852d4dc.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-600italic.17e5379f.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-600italic.6f4ba6aa.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-700.b8809d61.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-700.c9983d3d.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-700italic.02954bee.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-700italic.72e9af40.woff
src/web/gui/v1/static/media/material-icons.0509ab09.woff2 COMPONENT netdata DESTINATION ${WEB_DEST}/static/media)
    install(FILES src/web/gui/v1/index.html COMPONENT netdata DESTINATION ${WEB_DEST}/v1)

==> netdata_2.0.3+dfsg.orig.tar.xz: netdata-2.0.3+dfsg/src/web/gui/v1/dashboard_v1.cmake <==

    install(FILES src/web/gui/v1/asset-manifest.json
src/web/gui/v1/console.html
src/web/gui/v1/dash-example.html
src/web/gui/v1/dashboard-react.js
src/web/gui/v1/dashboard.css
src/web/gui/v1/dashboard.html
src/web/gui/v1/dashboard.js
src/web/gui/v1/dashboard.slate.css
src/web/gui/v1/demo.html
src/web/gui/v1/demo2.html
src/web/gui/v1/demosites.html
src/web/gui/v1/demosites2.html
src/web/gui/v1/favicon.ico
src/web/gui/v1/goto-host-from-alarm.html
src/web/gui/v1/index-node-view.html
src/web/gui/v1/infographic.html
src/web/gui/v1/manifest.json
src/web/gui/v1/precache-manifest.e2d3811ef5e4b7e75e1f56d6ee92ef2c.js
src/web/gui/v1/refresh-badges.js
src/web/gui/v1/robots.txt
src/web/gui/v1/service-worker.js
src/web/gui/v1/sitemap.xml
src/web/gui/v1/tv-react.html
src/web/gui/v1/tv.html COMPONENT dashboard DESTINATION ${WEB_DEST})
    install(FILES src/web/gui/v1/css/bootstrap-3.3.7.css
src/web/gui/v1/css/bootstrap-slate-flat-3.3.7.css
src/web/gui/v1/css/bootstrap-slider-10.0.0.min.css
src/web/gui/v1/css/bootstrap-theme-3.3.7.min.css
src/web/gui/v1/css/bootstrap-toggle-2.2.2.min.css
src/web/gui/v1/css/dashboard.css
src/web/gui/v1/css/dashboard.slate.css COMPONENT dashboard DESTINATION ${WEB_DEST}/css)
    install(FILES src/web/gui/v1/fonts/glyphicons-halflings-regular.eot
src/web/gui/v1/fonts/glyphicons-halflings-regular.svg
src/web/gui/v1/fonts/glyphicons-halflings-regular.ttf
src/web/gui/v1/fonts/glyphicons-halflings-regular.woff
src/web/gui/v1/fonts/glyphicons-halflings-regular.woff2 COMPONENT dashboard DESTINATION ${WEB_DEST}/fonts)
    install(FILES src/web/gui/v1/images/alert-128-orange.png
src/web/gui/v1/images/alert-128-red.png
src/web/gui/v1/images/alert-multi-size-orange.ico
src/web/gui/v1/images/alert-multi-size-red.ico
src/web/gui/v1/images/alerts.jpg
src/web/gui/v1/images/alerts.png
src/web/gui/v1/images/android-icon-144x144.png
src/web/gui/v1/images/android-icon-192x192.png
src/web/gui/v1/images/android-icon-36x36.png
src/web/gui/v1/images/android-icon-48x48.png
src/web/gui/v1/images/android-icon-72x72.png
src/web/gui/v1/images/android-icon-96x96.png
src/web/gui/v1/images/animated.gif
src/web/gui/v1/images/apple-icon-114x114.png
src/web/gui/v1/images/apple-icon-120x120.png
src/web/gui/v1/images/apple-icon-144x144.png
src/web/gui/v1/images/apple-icon-152x152.png
src/web/gui/v1/images/apple-icon-180x180.png
src/web/gui/v1/images/apple-icon-57x57.png
src/web/gui/v1/images/apple-icon-60x60.png
src/web/gui/v1/images/apple-icon-72x72.png
src/web/gui/v1/images/apple-icon-76x76.png
src/web/gui/v1/images/apple-icon-precomposed.png
src/web/gui/v1/images/apple-icon.png
src/web/gui/v1/images/banner-icon-144x144.png
src/web/gui/v1/images/check-mark-2-128-green.png
src/web/gui/v1/images/check-mark-2-multi-size-green.ico
src/web/gui/v1/images/dashboards.png
src/web/gui/v1/images/favicon-128.png
src/web/gui/v1/images/favicon-16x16.png
src/web/gui/v1/images/favicon-196x196.png
src/web/gui/v1/images/favicon-32x32.png
src/web/gui/v1/images/favicon-96x96.png
src/web/gui/v1/images/favicon.ico
src/web/gui/v1/images/home.png
src/web/gui/v1/images/ms-icon-144x144.png
src/web/gui/v1/images/ms-icon-150x150.png
src/web/gui/v1/images/ms-icon-310x150.png
src/web/gui/v1/images/ms-icon-310x310.png
src/web/gui/v1/images/ms-icon-36x36.png
src/web/gui/v1/images/ms-icon-70x70.png
src/web/gui/v1/images/netdata-logomark.svg
src/web/gui/v1/images/netdata.svg
src/web/gui/v1/images/nodeView.png
src/web/gui/v1/images/nodes.jpg
src/web/gui/v1/images/overview.png
src/web/gui/v1/images/packaging-beta-tag.svg
src/web/gui/v1/images/post.png
src/web/gui/v1/images/pricing.png
src/web/gui/v1/images/seo-performance-128.png COMPONENT dashboard DESTINATION ${WEB_DEST}/images)
    install(FILES src/web/gui/v1/lib/bootstrap-3.3.7.min.js
src/web/gui/v1/lib/bootstrap-slider-10.0.0.min.js
src/web/gui/v1/lib/bootstrap-table-1.11.0.min.js
src/web/gui/v1/lib/bootstrap-table-export-1.11.0.min.js
src/web/gui/v1/lib/bootstrap-toggle-2.2.2.min.js
src/web/gui/v1/lib/clipboard-polyfill-be05dad.js
src/web/gui/v1/lib/d3-4.12.2.min.js
src/web/gui/v1/lib/d3pie-0.2.1-netdata-3.js
src/web/gui/v1/lib/dygraph-c91c859.min.js
src/web/gui/v1/lib/dygraph-smooth-plotter-c91c859.js
src/web/gui/v1/lib/fontawesome-all-5.0.1.min.js
src/web/gui/v1/lib/gauge-1.3.2.min.js
src/web/gui/v1/lib/jquery-3.6.0.min.js
src/web/gui/v1/lib/jquery.easypiechart-97b5824.min.js
src/web/gui/v1/lib/jquery.peity-3.2.0.min.js
src/web/gui/v1/lib/jquery.sparkline-2.1.2.min.js
src/web/gui/v1/lib/lz-string-1.4.4.min.js
src/web/gui/v1/lib/pako-1.0.6.min.js
src/web/gui/v1/lib/perfect-scrollbar-0.6.15.min.js
src/web/gui/v1/lib/tableExport-1.6.0.min.js COMPONENT dashboard DESTINATION ${WEB_DEST}/lib)
    install(FILES src/web/gui/v1/static/css/2.c454aab8.chunk.css
src/web/gui/v1/static/css/2.c454aab8.chunk.css.map
src/web/gui/v1/static/css/4.a36e3b73.chunk.css
src/web/gui/v1/static/css/4.a36e3b73.chunk.css.map
src/web/gui/v1/static/css/main.53ba10f1.chunk.css
src/web/gui/v1/static/css/main.53ba10f1.chunk.css.map COMPONENT dashboard DESTINATION ${WEB_DEST}/static/css)
    install(FILES src/web/gui/v1/static/js/10.a5cd7d0e.chunk.js
src/web/gui/v1/static/js/10.a5cd7d0e.chunk.js.map
src/web/gui/v1/static/js/2.62d105c5.chunk.js
src/web/gui/v1/static/js/2.62d105c5.chunk.js.LICENSE
src/web/gui/v1/static/js/2.62d105c5.chunk.js.map
src/web/gui/v1/static/js/3.f137faca.chunk.js
src/web/gui/v1/static/js/3.f137faca.chunk.js.map
src/web/gui/v1/static/js/4.2dbcd906.chunk.js
src/web/gui/v1/static/js/4.2dbcd906.chunk.js.map
src/web/gui/v1/static/js/5.2f783a54.chunk.js
src/web/gui/v1/static/js/5.2f783a54.chunk.js.LICENSE
src/web/gui/v1/static/js/5.2f783a54.chunk.js.map
src/web/gui/v1/static/js/6.e1951239.chunk.js
src/web/gui/v1/static/js/6.e1951239.chunk.js.map
src/web/gui/v1/static/js/7.c2417fb0.chunk.js
src/web/gui/v1/static/js/7.c2417fb0.chunk.js.map
src/web/gui/v1/static/js/8.b4161ea2.chunk.js
src/web/gui/v1/static/js/8.b4161ea2.chunk.js.map
src/web/gui/v1/static/js/9.a4363968.chunk.js
src/web/gui/v1/static/js/9.a4363968.chunk.js.map
src/web/gui/v1/static/js/main.e248095a.chunk.js
src/web/gui/v1/static/js/main.e248095a.chunk.js.LICENSE
src/web/gui/v1/static/js/main.e248095a.chunk.js.map
src/web/gui/v1/static/js/runtime-main.08abed8f.js
src/web/gui/v1/static/js/runtime-main.08abed8f.js.map COMPONENT dashboard DESTINATION ${WEB_DEST}/static/js)
    install(FILES src/web/gui/v1/static/media/ibm-plex-sans-latin-100.245539db.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-100.9a582f3a.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-100italic.1ea7c5d2.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-100italic.3c34cf08.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-200.67524c36.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-200.bf72c841.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-200italic.52df2560.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-200italic.bbc2d552.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-300.10bb6a0a.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-300.9e1c48af.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-300italic.c76f2ab5.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-300italic.d3566d5b.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-400.263d6267.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-400.a2c56f94.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-400italic.272f8611.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-400italic.89a93a1b.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-500.0866c244.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-500.f6d5c5d5.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-500italic.ccd41bd1.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-500italic.ffd12d59.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-600.337b1651.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-600.7852d4dc.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-600italic.17e5379f.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-600italic.6f4ba6aa.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-700.b8809d61.woff
src/web/gui/v1/static/media/ibm-plex-sans-latin-700.c9983d3d.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-700italic.02954bee.woff2
src/web/gui/v1/static/media/ibm-plex-sans-latin-700italic.72e9af40.woff
src/web/gui/v1/static/media/material-icons.0509ab09.woff2 COMPONENT dashboard DESTINATION ${WEB_DEST}/static/media)
    install(FILES src/web/gui/v1/index.html COMPONENT dashboard DESTINATION ${WEB_DEST}/v1)
